@@ -38,4 +38,7 @@ api_funcs = {
 image_funcs = {
     'self': 'imagedeal',
     '-stbg': 'set_img_background',
+    '-v2gif': 'v2gif',
+    '-rmaudio': 'rmaudio',
+    '-v2mp4': 'v2mp4'
 }
